﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Windows.Data;
using Infragistics.Controls.Grids.Primitives;
using Infragistics.Controls.Grids;

namespace Infragistics.Custom
{
    public class CheckboxStateColumnContentProvider : ColumnContentProviderBase
    {
        #region Members

       public CheckBox _cb; 

        #endregion // Members

        #region Overrides

        /// <summary>
        /// Return the element that should be displayed in the cell. 
        /// </summary>
        /// <param name="cell"></param>
        /// <param name="cellBinding"></param>
        /// <returns></returns>
        public override FrameworkElement ResolveDisplayElement(Cell cell, Binding cellBinding)
        {
            if (this._cb == null)
            {
                this._cb = new CheckBox();
                _cb.Checked += new RoutedEventHandler (_cb_Checked);
            }

            // Setup the binding to the Checkbox.
            if (cellBinding != null)
            {
                this._cb.SetBinding(CheckBox.IsCheckedProperty, cellBinding);
            }

            return this._cb;
        }

        void _cb_Checked (object sender, RoutedEventArgs e)
        {
          
        }

        public override void AdjustDisplayElement(Cell cell)
        {
            // This gets called anytime something needs to be updated in the UI, such as when is recycled
            // SO update the DataContext, so that the binding of the Checkbox updates.
            this._cb.DataContext = cell;
        }

        protected override Binding ResolveBinding(Cell cell)
        {
            // Create a Binding that binds the "IsChecked" property of the CheckboxStateCell
            Binding b = new Binding("IsChecked");
            b.Mode = BindingMode.TwoWay;
            return b;
        }

        // No need to support Editing, so both of these methods can just return null.
        protected override FrameworkElement ResolveEditorControl(Cell cell, object editorValue, double availableWidth, double availableHeight, Binding editorBinding)
        {
            return null;
        }

        // No need to support Editing, so both of these methods can just return null.
        public override object ResolveValueFromEditor(Cell cell)
        {
            return null;
        }

        #endregion // Overrides
    }
}
